@@ -14,7 +14,6 @@ from drms import __version__
 project = "drms"
 author = "The SunPy Project"
 copyright = f"{datetime.datetime.now().year}, {author}"  # NOQA: A001
-
 # The full version, including alpha/beta/rc tags
 release = __version__
 is_development = ".dev" in __version__
@@ -37,25 +36,14 @@ extensions = [
     "sphinx.ext.todo",
     "sphinx.ext.viewcode",
 ]
-
-# Set automodapi to generate files inside the generated directory
 automodapi_toctreedirnm = "generated/api"
-# List of patterns, relative to source directory, that match files and
-# directories to ignore when looking for source files.
-# This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
-# The suffix(es) of source filenames.
-# You can specify multiple suffix as a list of string:
 source_suffix = ".rst"
-# The master toctree document.
 master_doc = "index"
-# The reST default role (used for this markup: `text`) to use for all
-# documents. Set to the "smart" one.
 default_role = "obj"
 
 # -- Options for hoverxref -----------------------------------------------------
 if os.environ.get("READTHEDOCS"):
-    # Building on Read the Docs
     hoverxref_api_host = "https://readthedocs.org"
     if os.environ.get("PROXIED_API_ENDPOINT"):
         # Use the proxied API endpoint
@@ -65,7 +53,6 @@ if os.environ.get("READTHEDOCS"):
 hoverxref_tooltip_maxwidth = 600  # RTD main window is 696px
 hoverxref_auto_ref = True
 hoverxref_mathjax = True
-# hoverxref has to be applied to these
 hoverxref_domains = ["py"]
 hoverxref_role_types = {
     # roles with py domain
@@ -111,7 +98,9 @@ intersphinx_mapping = {
 }
 
 # -- Options for HTML output -------------------------------------------------
-# Render inheritance diagrams in SVG
+# JSOC email os env
+# see https://github.com/sunpy/sunpy/wiki/Home:-JSOC
+os.environ["JSOC_EMAIL"] = "jsoc@sunpy.org"
 graphviz_output_format = "svg"
 sphinx_gallery_conf = {
     "backreferences_dir": Path("generated") / "modules",
