@@ -1,10 +1,10 @@
 import pytest
 
 
-@pytest.mark.jsoc
-@pytest.mark.remote_data
+@pytest.mark.jsoc()
+@pytest.mark.remote_data()
 @pytest.mark.parametrize(
-    "series, pkeys, segments",
+    ("series", "pkeys", "segments"),
     [
         ("hmi.v_45s", ["T_REC", "CAMERA"], ["Dopplergram"]),
         ("hmi.m_720s", ["T_REC", "CAMERA"], ["magnetogram"]),
@@ -21,10 +21,10 @@ def test_series_info_basic(jsoc_client, series, pkeys, segments):
         assert s in si.segments.index
 
 
-@pytest.mark.jsoc
-@pytest.mark.remote_data
+@pytest.mark.jsoc()
+@pytest.mark.remote_data()
 @pytest.mark.parametrize(
-    "series, pkeys",
+    ("series", "pkeys"),
     [
         ("hmi.v_45s", ["T_REC", "CAMERA"]),
         ("hmi.m_720s", ["T_REC", "CAMERA"]),
