@@ -24,7 +24,7 @@ def _split_arg(arg):
     Split a comma-separated string into a list.
     """
     if isinstance(arg, str):
-        arg = [it for it in re.split(r"[\s,]+", arg) if it]
+        return [it for it in re.split(r"[\s,]+", arg) if it]
     return arg
 
 
@@ -36,7 +36,7 @@ def _extract_series_name(ds):
     return m.group(1) if m is not None else None
 
 
-def to_datetime(tstr, force=False):
+def to_datetime(tstr, *, force=False):
     """
     Parse JSOC time strings.
 
@@ -47,8 +47,8 @@ def to_datetime(tstr, force=False):
 
     The current implementation only tries to convert typical HMI time
     strings, with a format like "%Y.%m.%d_%H:%M:%S_TAI", to an ISO time
-    string, that is then parsed by pandas. Note that "_TAI", aswell as
-    other timezone indentifiers like "Z", will not be taken into
+    string, that is then parsed by pandas. Note that "_TAI", as well as
+    other timezone identifiers like "Z", will not be taken into
     account, so the result will be a naive timestamp without any
     associated timezone.
 
@@ -60,9 +60,9 @@ def to_datetime(tstr, force=False):
     Parameters
     ----------
     tstr : str or List[str] or pandas.Series
-        DateTime strings.
+        Datetime strings.
     force : bool
-        Set to True to omit the endswith('_TAI') check.
+        Set to True to omit the ``endswith('_TAI')`` check.
 
     Returns
     -------
