@@ -13,9 +13,9 @@ import os
 import drms
 
 ###############################################################################
-# Create DRMS client, uses the JSOC baseurl by default, set debug=True to see the DRMS query URLs.
+# First we will create a `drms.Client`, using the JSOC baseurl.
 
-client = drms.Client(verbose=True)
+client = drms.Client()
 
 # This example requires a registered export email address. You can register
 # JSOC exports at: http://jsoc.stanford.edu/ajax/register_email.html
@@ -31,9 +31,9 @@ qstr = "hmi.ic_720s[2015.01.01_00:00:00_TAI/10d@1d]{continuum}"
 print(f"Data export query:\n  {qstr}\n")
 print("Submitting export request...")
 result = client.export(qstr, email=email)
-print(f"len(r.urls) file(s) available for download.\n")
+print(f"{len(result.urls)} file(s) available for download.\n")
 
 # Print download URLs.
 for _, row in result.urls[["record", "url"]].iterrows():
-    print(f"REC: {row.record}")
+    print(f"REC(ORD): {row.record}")
     print(f"URL: {row.url}\n")
