@@ -15,25 +15,24 @@ downloading FITS files instead of text files.
 """
 
 import os
+from pathlib import Path
 
 import drms
 
 ###############################################################################
-# Create DRMS client, uses the JSOC baseurl by default, set debug=True to see the DRMS query URLs.
+# First we will create a `drms.Client`, using the JSOC baseurl.
 
-client = drms.Client(verbose=True)
+client = drms.Client()
 
 # This example requires a registered export email address. You can register
 # JSOC exports at: http://jsoc.stanford.edu/ajax/register_email.html
 # You must supply your own email.
 email = os.environ["JSOC_EMAIL"]
 
-# Download directory
-out_dir = "downloads"
-
 # Create download directory if it does not exist yet.
-if not os.path.exists(out_dir):
-    os.makedirs(out_dir)
+out_dir = Path("downloads")
+if not out_dir.exists():
+    Path(out_dir).mkdir(parents=True)
 
 ###############################################################################
 # Construct the DRMS query string: "Series[Carrington rotation][Carrington longitude]{data segments}"
