@@ -10,12 +10,13 @@ import textwrap
 import drms
 
 ###############################################################################
-# Make the basic query.
-# Create DRMS JSON client, use debug=True to see the query URLs
+# First we will create a `drms.Client`, using the JSOC baseurl.
 client = drms.Client()
 
-# Get all available HMI series
-hmi_series = client.series(r"hmi\.", full=True)
+###############################################################################
+# Get all available HMI series and print their names, prime keys and notes.
+
+hmi_series = client.series(regex=r"hmi\.", full=True)
 
 # Print series names, prime-keys (pkeys) and notes
 for series in hmi_series.index:
